@@ -19,11 +19,12 @@ import uvicorn
 
 # -- own --
 from . import debug
+from .common import detect_env
 from .utils.log import init as init_logging, patch_formatter as patch_log_formatter
 
 
 # -- code --
-log = logging.getLogger('openbayes-serv')
+log = logging.getLogger('openbayes_serving.serv')
 
 
 class ServingError(Exception):
@@ -36,19 +37,6 @@ class ServingError(Exception):
 
 
 # -----------------------------
-def detect_env():
-    if sys.platform == 'win32':
-        return 'local'
-
-    if os.environ.get('OPENBAYES_JOB_URL'):
-        return 'gear'
-
-    if os.environ.get('OPENBAYES_SERVING_PRODUCTION'):
-        return 'production'
-
-    return 'local'
-
-
 class ONNXInit:
     @staticmethod
     def register_parameters(parser):
@@ -295,7 +283,6 @@ def make_app(predictor_cls):
         log.info('检测到本地开发环境，开启调试模式')
         app.register_blueprint(predict_blueprint, url_prefix='/')
         debug.install(app)
-        # app = WSGILogger(app)
     elif env == 'gear':
         log.info('检测到 Openbayes 算力容器环境，开启调试模式')
 
@@ -311,11 +298,10 @@ def make_app(predictor_cls):
 
         app.register_blueprint(predict_blueprint, url_prefix=prefix)
         debug.install(app, url_prefix=prefix)
-        # app = WSGILogger(app)
 
     elif env == 'production':
         log.info('检测到生产环境，关闭调试模式。请求的统计信息可以在 Openbayes 的控制台上查看。')
-        app.register_blueprint(predict_blueprint)
+        app.register_blueprint(predict_blueprint, url_prefix='/')
 
     return app
 
@@ -339,16 +325,6 @@ def run(predictor_cls):
     log.info('-' * 60)
     server.run()
 
-    # try:
-    #     bjoern.listen(app, options.host, options.port)
-    # except OSError:
-    #     log.exception('绑定服务端口失败，请确认是否有其他程序占用 %s 端口（有开启多个实例吗？）', options.port)
-    #     sys.exit(1)
-
-    # log.info(f'Openbayes Serving 开始服务（{options.host}:{options.port}）')
-    # bjoern.run()
-
-
 # def obt.serv.check(pattern, obj=<payload>):
 #     '''检查指定的对象是否满足 pattern，在 predict 处使用，默认检查 payload。要实现一个后门，用来给前端暴露这个 pattern 具体是什么。'''
 
